@@ -1,7 +1,7 @@
 import requests as r
 import numpy as np
 
-url = 'https://f6d58753.ngrok.io'
+url = r.get('https://api-covid-ufrgs.herokuapp.com/links').json()[-1]['link']
 
 class Municipios:
 	def __init__(self, url=url):
@@ -12,13 +12,17 @@ class Municipios:
 		d = self.data
 		arr = []
 		for mp in d:
-			arr.append([mp['pop_senso_2010'], mp['pop_est_2019']])
+			arr.append([mp['nome'], mp['pop_senso_2010'], mp['pop_est_2019'], mp['mesoregiao']])
 		return np.asarray(arr)
 
 class Distancias:
 	def __init__(self,url=url):
 		self.url = url + '/index/distancias'
-		self.mps = r.get(self.url).json()
+		try:
+			self.mps = r.get(self.url).json()
+		except NameError as err:
+			print(err);
+
 
 	def matriz_distancia(self):
 		arr_arr = []
@@ -29,9 +33,29 @@ class Distancias:
 			arr_arr.append(arr)
 		return np.asarray(arr_arr)
 
-	def matriz_distancia_simetrica_media(self):
-		matriz = self.matriz_distancia()
-		return matriz.transpose() + matriz
+	def matriz_limitrofes(self):
+		arr_arr = []
+		for i in range(0,167):
+			arr = []
+			for mp in self.mps[i*167:(i+1)*167]:
+				if(mp['limitrofes'] == 1):
+					arr.append(mp['distancia'])
+				elif(mp['limitrofes'] == 0):
+					arr.append(0)
+			arr_arr.append(arr)
+		return np.asarray(arr_arr)
+
+	def matriz_distancia_raio(self, raio):
+		arr_arr = []
+		for i in range(0,167):
+			arr = []
+			for mp in self.mps[i*167:(i+1)*167]:
+				if(mp['distancia'] <= raio):
+					arr.append(mp['distancia'])
+				else:
+					arr.append(0)
+			arr_arr.append(arr)
+		return np.array(arr_arr)
 
 class Rodoviarias:
 	def __init__(self, url=url):
